========================================
Patrole: Tempest Plugin for RBAC Testing
========================================

Overview
========

.. toctree::
   :maxdepth: 2

   overview

RBAC Overview
-------------

.. toctree::
   :maxdepth: 2

   rbac-overview
   multi-policy-validation

User's Guide
============

Patrole Configuration Guide
---------------------------

.. toctree::
   :maxdepth: 2

   configuration

Patrole Installation Guide
--------------------------

.. toctree::
   :maxdepth: 2

   installation

Field Guides
============

.. toctree::
   :maxdepth: 1

   field_guide/index
   field_guide/rbac

Developer's Guide
=================

.. toctree::
   :maxdepth: 1

   HACKING
   REVIEWING
   test_writing_guide

Framework
---------

.. toctree::
   :maxdepth: 3

   framework/overview
   framework/rbac_validation
   framework/rbac_authority
   framework/policy_authority
   framework/requirements_authority
   framework/rbac_utils
   framework/code/modules

Indices and tables
==================

* :ref:`search`
